@@ -12,14 +12,15 @@ from hein_robots.base import robot_arms
 class UR3Arm(robot_arms.RobotArm):
     def __init__(self, host: str = '192.168.0.100', default_velocity: float = 250, max_velocity: float = 500, position_units: str = Units.MILLIMETERS,
                  default_joint_velocity: float = 20.0, max_joint_velocity = 180.0, gripper_default_velocity: float = 0.5, gripper_default_force: float = 0.5,
-                 gripper_id: int = 1, connect: bool = True):
+                 gripper_id: int = 1, gripper_base_port: int = 63352, gripper_connect: bool = True, connect: bool = True):
         super().__init__(default_velocity=default_velocity, max_velocity=max_velocity, position_units=position_units,
                          gripper_default_velocity=gripper_default_velocity, gripper_default_force=gripper_default_force)
         self._default_joint_velocity = default_joint_velocity
         self.max_joint_velocity = max_joint_velocity
         self.host = host
         self._robot: Optional[urx.Robot] = None
-        self.gripper = RobotiqGripper(self.host, id=gripper_id, connect=False)
+        self.gripper = RobotiqGripper(self.host, id=gripper_id, base_port=gripper_base_port, connect=False)
+        self.gripper_connect = gripper_connect
 
         if connect:
             self.connect()
@@ -94,7 +95,10 @@ class UR3Arm(robot_arms.RobotArm):
         while retries > 0:
             try:
                 self._robot = urx.Robot(self.host)
-                self.gripper.connect()
+
+                if self.gripper_connect:
+                    self.gripper.connect()
+
                 return
             except ursecmon.TimeoutException:
                 print('Retrying')
